pub(crate) struct LLVMAbi<A: Architecture = TargetArchitecture> {
pub(crate) architecture: A,
}Expand description
LLVM ABI lowering shared by all supported architectures.
Fields
architecture: AImplementations
Sourceimpl<A: Architecture> LLVMAbi<A>
We need to produce different LLVM IR for different platforms. (Contrary to
popular knowledge LLVM IR is not intended to be portable in that way.) This
trait deals with differences between function signatures on different
targets.
impl<A: Architecture> LLVMAbi<A>
We need to produce different LLVM IR for different platforms. (Contrary to popular knowledge LLVM IR is not intended to be portable in that way.) This trait deals with differences between function signatures on different targets.
Sourcepub(crate) fn get_vmctx_ptr_param<'ctx>(
&self,
func_value: &FunctionValue<'ctx>,
) -> PointerValue<'ctx>
pub(crate) fn get_vmctx_ptr_param<'ctx>( &self, func_value: &FunctionValue<'ctx>, ) -> PointerValue<'ctx>
Given a function definition, retrieve the parameter that is the vmctx pointer.
Sourcepub(crate) fn get_m0_ptr_param<'ctx>(
&self,
func_value: &FunctionValue<'ctx>,
) -> PointerValue<'ctx>
pub(crate) fn get_m0_ptr_param<'ctx>( &self, func_value: &FunctionValue<'ctx>, ) -> PointerValue<'ctx>
Given a function definition, retrieve the parameter that is the pointer to the first – number 0 – local memory.
Sourcepub(crate) fn args_to_call<'ctx>(
&self,
alloca_builder: &Builder<'ctx>,
func_sig: &FuncSig,
llvm_fn_ty: &FunctionType<'ctx>,
ctx_ptr: PointerValue<'ctx>,
values: &[BasicValueEnum<'ctx>],
intrinsics: &Intrinsics<'ctx>,
m0: Option<PointerValue<'ctx>>,
sret_ptr: Option<PointerValue<'ctx>>,
) -> Result<Vec<BasicValueEnum<'ctx>>, CompileError>
pub(crate) fn args_to_call<'ctx>( &self, alloca_builder: &Builder<'ctx>, func_sig: &FuncSig, llvm_fn_ty: &FunctionType<'ctx>, ctx_ptr: PointerValue<'ctx>, values: &[BasicValueEnum<'ctx>], intrinsics: &Intrinsics<'ctx>, m0: Option<PointerValue<'ctx>>, sret_ptr: Option<PointerValue<'ctx>>, ) -> Result<Vec<BasicValueEnum<'ctx>>, CompileError>
Marshall wasm stack values into function parameters.
Sourcepub(crate) fn llvm_fn_uses_sret<'ctx>(
&self,
llvm_fn_ty: &FunctionType<'ctx>,
func_sig: &FuncSig,
) -> bool
pub(crate) fn llvm_fn_uses_sret<'ctx>( &self, llvm_fn_ty: &FunctionType<'ctx>, func_sig: &FuncSig, ) -> bool
Whether a concrete LLVM function type uses an sret parameter for the given wasm signature.
Sourceimpl<A: Architecture> LLVMAbi<A>
impl<A: Architecture> LLVMAbi<A>
pub(crate) fn func_type_to_llvm<'ctx>( &self, context: &'ctx Context, intrinsics: &Intrinsics<'ctx>, offsets: Option<&VMOffsets>, sig: &FuncSig, include_m0_param: bool, ) -> Result<(FunctionType<'ctx>, Vec<(Attribute, AttributeLoc)>), CompileError>
pub(crate) fn rets_from_call<'ctx>( &self, builder: &Builder<'ctx>, intrinsics: &Intrinsics<'ctx>, call_site: CallSiteValue<'ctx>, func_sig: &FuncSig, ) -> Result<Vec<BasicValueEnum<'ctx>>, CompileError>
pub(crate) fn pack_values_for_register_return<'ctx>( &self, intrinsics: &Intrinsics<'ctx>, builder: &Builder<'ctx>, values: &[BasicValueEnum<'ctx>], func_sig: &FuncSig, func_type: &FunctionType<'ctx>, ) -> Result<BasicValueEnum<'ctx>, CompileError>