pub struct LLVM {
pub(crate) enable_nan_canonicalization: bool,
pub(crate) enable_non_volatile_memops: bool,
pub(crate) enable_readonly_funcref_table: bool,
pub(crate) enable_verifier: bool,
pub(crate) enable_perfmap: bool,
pub(crate) opt_level: LLVMOptLevel,
is_pic: bool,
pub(crate) callbacks: Option<LLVMCallbacks>,
pub(crate) middlewares: Vec<Arc<dyn ModuleMiddleware>>,
pub(crate) num_threads: NonZero<usize>,
pub(crate) verbose_asm: bool,
}Fields
enable_nan_canonicalization: boolenable_non_volatile_memops: boolenable_readonly_funcref_table: boolenable_verifier: boolenable_perfmap: boolopt_level: LLVMOptLevelis_pic: boolcallbacks: Option<LLVMCallbacks>middlewares: Vec<Arc<dyn ModuleMiddleware>>The middleware chain.
num_threads: NonZero<usize>Number of threads to use when compiling a module.
verbose_asm: boolImplementations
Sourceimpl LLVM
impl LLVM
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new configuration object with the default configuration specified.
Sourcepub fn opt_level(&mut self, opt_level: LLVMOptLevel) -> &mut Self
pub fn opt_level(&mut self, opt_level: LLVMOptLevel) -> &mut Self
The optimization levels when optimizing the IR.
pub fn num_threads(&mut self, num_threads: NonZero<usize>) -> &mut Self
pub fn verbose_asm(&mut self, verbose_asm: bool) -> &mut Self
Sourcepub fn callbacks(&mut self, callbacks: Option<LLVMCallbacks>) -> &mut Self
pub fn callbacks(&mut self, callbacks: Option<LLVMCallbacks>) -> &mut Self
Callbacks that will triggered in the different compilation phases in LLVM.
Sourcepub fn non_volatile_memops(
&mut self,
enable_non_volatile_memops: bool,
) -> &mut Self
pub fn non_volatile_memops( &mut self, enable_non_volatile_memops: bool, ) -> &mut Self
For the LLVM compiler, we can use non-volatile memory operations which lead to a better performance (but are not 100% SPEC compliant).
Sourcepub fn readonly_funcref_table(
&mut self,
enable_readonly_funcref_table: bool,
) -> &mut Self
pub fn readonly_funcref_table( &mut self, enable_readonly_funcref_table: bool, ) -> &mut Self
Enables treating eligible funcref tables as read-only so the backend can place them in read-only data.
fn reloc_mode(&self, binary_format: BinaryFormat) -> RelocMode
fn code_model(&self, binary_format: BinaryFormat) -> CodeModel
pub(crate) fn target_operating_system(&self, target: &Target) -> OperatingSystem
pub(crate) fn target_binary_format(&self, target: &Target) -> BinaryFormat
fn target_triple(&self, target: &Target) -> TargetTriple
Sourcepub fn target_machine(&self, target: &Target) -> TargetMachine
pub fn target_machine(&self, target: &Target) -> TargetMachine
Generates the target machine for the current target
pub(crate) fn target_machine_with_opt( &self, target: &Target, opt_style: OptimizationStyle, ) -> TargetMachine